EvaluationOnlyModel
===================

.. currentmodule:: pykeen.models

.. autoclass:: EvaluationOnlyModel
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~EvaluationOnlyModel.can_slice_h
      ~EvaluationOnlyModel.can_slice_r
      ~EvaluationOnlyModel.can_slice_t

   .. rubric:: Methods Summary

   .. autosummary::

      ~EvaluationOnlyModel.collect_regularization_term
      ~EvaluationOnlyModel.score_hrt
      ~EvaluationOnlyModel.score_r

   .. rubric:: Attributes Documentation

   .. autoattribute:: can_slice_h
   .. autoattribute:: can_slice_r
   .. autoattribute:: can_slice_t

   .. rubric:: Methods Documentation

   .. automethod:: collect_regularization_term
   .. automethod:: score_hrt
   .. automethod:: score_r
